@@ -41,15 +41,6 @@ enum
   PROP_MODEL,
 };
 
-enum
-{
-  ITEM_REMOVED,
-
-  LAST_SIGNAL
-};
-
-static guint signals[LAST_SIGNAL];
-
 G_DEFINE_TYPE (EphyWebOverview, ephy_web_overview, G_TYPE_OBJECT)
 
 typedef struct {
@@ -113,15 +104,6 @@ overview_item_free (OverviewItem *item)
   g_slice_free (OverviewItem, item);
 }
 
-static void
-ephy_web_overview_web_page_uri_changed (WebKitWebPage *web_page,
-                                        GParamSpec *spec,
-                                        EphyWebOverview *overview)
-{
-  if (g_strcmp0 (webkit_web_page_get_uri (web_page), "ephy-about:overview") != 0)
-    g_object_unref (overview);
-}
-
 static void
 update_thumbnail_element_style (WebKitDOMElement *thumbnail,
                                 const char *path)
@@ -382,28 +364,6 @@ ephy_web_overview_dispose (GObject *object)
   G_OBJECT_CLASS (ephy_web_overview_parent_class)->dispose (object);
 }
 
-static void
-ephy_web_overview_web_view_destroyed (EphyWebOverview *overview,
-                                      GObject *destroyed_web_view)
-{
-  overview->priv->web_page = NULL;
-  g_object_unref (overview);
-}
-
-static void
-ephy_web_overview_finalize (GObject *object)
-{
-  EphyWebOverview *overview = EPHY_WEB_OVERVIEW (object);
-
-  if (overview->priv->web_page) {
-    g_object_weak_unref (G_OBJECT (overview->priv->web_page),
-                         (GWeakNotify)ephy_web_overview_web_view_destroyed,
-                         overview);
-  }
-
-  G_OBJECT_CLASS (ephy_web_overview_parent_class)->finalize (object);
-}
-
 static void
 ephy_web_overview_constructed (GObject *object)
 {
@@ -411,13 +371,6 @@ ephy_web_overview_constructed (GObject *object)
 
   G_OBJECT_CLASS (ephy_web_overview_parent_class)->constructed (object);
 
-  g_object_weak_ref (G_OBJECT (overview->priv->web_page),
-                     (GWeakNotify)ephy_web_overview_web_view_destroyed,
-                     overview);
-
-  g_signal_connect_object (overview->priv->web_page, "notify::uri",
-                           G_CALLBACK (ephy_web_overview_web_page_uri_changed),
-                           overview, 0);
   g_signal_connect_object (overview->priv->web_page, "document-loaded",
                            G_CALLBACK (ephy_web_overview_document_loaded),
                            overview, 0);
@@ -439,7 +392,6 @@ ephy_web_overview_class_init (EphyWebOverviewClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->dispose = ephy_web_overview_dispose;
-  object_class->finalize = ephy_web_overview_finalize;
   object_class->constructed = ephy_web_overview_constructed;
   object_class->set_property = ephy_web_overview_set_property;
 
@@ -462,15 +414,6 @@ ephy_web_overview_class_init (EphyWebOverviewClass *klass)
                                                         G_PARAM_CONSTRUCT_ONLY |
                                                         G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
-  signals[ITEM_REMOVED] =
-    g_signal_new ("item-removed",
-                  EPHY_TYPE_WEB_OVERVIEW,
-                  G_SIGNAL_RUN_LAST,
-                  0, NULL, NULL,
-                  g_cclosure_marshal_VOID__STRING,
-                  G_TYPE_NONE, 1,
-                  G_TYPE_STRING);
-
   g_type_class_add_private (object_class, sizeof(EphyWebOverviewPrivate));
 }
 
@@ -492,76 +435,3 @@ ephy_web_overview_new (WebKitWebPage *web_page,
                        "model", model,
                        NULL);
 }
-
-static JSValueRef
-remove_item_from_overview_cb (JSContextRef context,
-                              JSObjectRef function,
-                              JSObjectRef this_object,
-                              size_t argument_count,
-                              const JSValueRef arguments[],
-                              JSValueRef *exception)
-{
-  EphyWebOverview *overview;
-  JSStringRef result_string_js;
-  size_t max_size;
-  char *result_string;
-
-  overview = EPHY_WEB_OVERVIEW (JSObjectGetPrivate (this_object));
-
-  result_string_js = JSValueToStringCopy (context, arguments[0], NULL);
-  max_size = JSStringGetMaximumUTF8CStringSize (result_string_js);
-
-  result_string = g_malloc (max_size);
-  JSStringGetUTF8CString (result_string_js, result_string, max_size);
-  g_signal_emit (overview, signals[ITEM_REMOVED], 0, result_string);
-  JSStringRelease (result_string_js);
-  g_free (result_string);
-
-  return JSValueMakeUndefined (context);
-}
-
-static const JSStaticFunction overview_static_funcs[] =
-{
-  { "removeItemFromOverview", remove_item_from_overview_cb, kJSPropertyAttributeReadOnly | kJSPropertyAttributeDontDelete },
-  { NULL, NULL, 0 }
-};
-
-static const JSClassDefinition overview_class_def =
-{
-  0,                     /* version */
-  kJSClassAttributeNone, /* attributes */
-  "Overview",            /* className */
-  NULL,                  /* parentClass */
-  NULL,                  /* staticValues */
-  overview_static_funcs, /* staticFunctions */
-  NULL,                  /* initialize */
-  NULL,                  /* finalize */
-  NULL,                  /* hasProperty */
-  NULL,                  /* getProperty */
-  NULL,                  /* setProperty */
-  NULL,                  /* deleteProperty */
-  NULL,                  /* getPropertyNames */
-  NULL,                  /* callAsFunction */
-  NULL,                  /* callAsConstructor */
-  NULL,                  /* hasInstance */
-  NULL                   /* convertToType */
-};
-
-void
-ephy_web_overview_init_js (EphyWebOverview *overview,
-                           JSGlobalContextRef context)
-{
-  JSObjectRef global_object;
-  JSClassRef class_def;
-  JSObjectRef class_object;
-  JSStringRef str;
-
-  global_object = JSContextGetGlobalObject (context);
-
-  class_def = JSClassCreate (&overview_class_def);
-  class_object = JSObjectMake (context, class_def, overview);
-  str = JSStringCreateWithUTF8CString ("Overview");
-  JSObjectSetProperty (context, global_object, str, class_object, kJSPropertyAttributeNone, NULL);
-  JSStringRelease (str);
-  JSClassRelease (class_def);
-}
